@@ -1,3 +1,5 @@
+import sys
+
 def main(args):
   commands = ['home', 'next', 'back', 'check', 'progress']
 
@@ -10,4 +12,4 @@ def main(args):
   print()
 
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main(sys.argv)
\ No newline at end of file
